# robotslacker-sqlcli

robotslacker-sqlcli is a SQL command console tool.


## Install

Install robotslacker-sqlcli

    pip install -U robotslacker-sqlcli

## Usage
    
    https://github.com/robotslacker/sqlcli/blob/master/Doc.md
